from distutils.core import setup

setup(
  name='linen',
  version='0.0.1',
  author='Unknown',
  author_email='vipcalio@gmail.com',
  url='https://github.com',
  license="MIT",
  long_description="linen is what you want",
  packages=['linen'],
  scripts=[]
)
